@@ -16,6 +16,8 @@ class Machine(object):
         self.username = ROOT_USER
         self.password = ROOT_PASSWORD
         self.islinked = False
+        self.splunk_username = "admin"
+        self.splunk_password = "notchangeme"
 
     @property
     def name(self):
@@ -67,6 +69,30 @@ class Machine(object):
         """
         return self.container.ports["22/tcp"][0]["HostPort"]
 
+    @property
+    def splunkd_public_host(self):
+        """
+        represent the ssh public port of a machine
+        :return:
+
+        >>> from rider.environment import Environment
+        >>> env = Environment.get_environments('jacktestapi2_cluster')
+        >>> env.indexer.machines[0].splunk_public_host
+        """
+        return self.ssh_public_host
+
+    @property
+    def splunkd_public_port(self):
+        """
+        represent the ssh public port of a machine
+        :return:
+
+        >>> from rider.environment import Environment
+        >>> env = Environment.get_environments('jacktestapi2_cluster')
+        >>> env.indexer.machines[0].splunk_public_port
+        """
+        return self.container.ports["8089/tcp"][0]["HostPort"]
+
     @property
     def ssh_host_string(self):
         """
